@@ -1,6 +1,6 @@
 from datetime import date, datetime
 from pathlib import Path
-from typing import Any, Callable, Dict, IO, List, Tuple, Union
+from typing import Any, Callable, Dict, IO, List, Tuple, Union, Optional
 
 from coinmetrics.constants import PagingFrom
 
@@ -10,3 +10,4 @@ DataRetrievalFuncType = Callable[[str, Dict[str, Any]], DataReturnType]
 UrlParamTypes = Union[
     str, List[str], Tuple[str], PagingFrom, int, datetime, date, bool, None
 ]
+MessageHandlerType = Optional[Callable[[Any, str], None]]
